==> certmanager-model-v1alpha2-6.6.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/VaultIssuerFluentImpl.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class VaultIssuerFluentImpl<A extends VaultIssuerFluent<A>> extends BaseFluent<A> implements VaultIssuerFluent<A>{
  public VaultIssuerFluentImpl() {
  }
  public VaultIssuerFluentImpl(VaultIssuer instance) {
    this.withAuth(instance.getAuth()); 
    this.withCaBundle(instance.getCaBundle()); 
    this.withNamespace(instance.getNamespace()); 
    this.withPath(instance.getPath()); 
    this.withServer(instance.getServer()); 
  }
  private VaultAuthBuilder auth;
  private String caBundle;
  private String namespace;
  private String path;
  private String server;
  
  /**
   * This method has been deprecated, please use method buildAuth instead.
   * @return The buildable object.
   */
  @Deprecated
  public VaultAuth getAuth() {
    return this.auth!=null ?this.auth.build():null;
  }
  public VaultAuth buildAuth() {
    return this.auth!=null ?this.auth.build():null;
  }
  public A withAuth(VaultAuth auth) {
    _visitables.get("auth").remove(this.auth);
    if (auth!=null){ this.auth= new VaultAuthBuilder(auth); _visitables.get("auth").add(this.auth);} else { this.auth = null; _visitables.get("auth").remove(this.auth); } return (A) this;
  }
  public Boolean hasAuth() {
    return this.auth != null;
  }
  public VaultIssuerFluent.AuthNested<A> withNewAuth() {
    return new VaultIssuerFluentImpl.AuthNestedImpl();
  }
  public VaultIssuerFluent.AuthNested<A> withNewAuthLike(VaultAuth item) {
    return new VaultIssuerFluentImpl.AuthNestedImpl(item);
  }
  public VaultIssuerFluent.AuthNested<A> editAuth() {
    return withNewAuthLike(getAuth());
  }
  public VaultIssuerFluent.AuthNested<A> editOrNewAuth() {
    return withNewAuthLike(getAuth() != null ? getAuth(): new VaultAuthBuilder().build());
  }
  public VaultIssuerFluent.AuthNested<A> editOrNewAuthLike(VaultAuth item) {
    return withNewAuthLike(getAuth() != null ? getAuth(): item);
  }
  public String getCaBundle() {
    return this.caBundle;
  }
  public A withCaBundle(String caBundle) {
    this.caBundle=caBundle; return (A) this;
  }
  public Boolean hasCaBundle() {
    return this.caBundle != null;
  }
  public String getNamespace() {
    return this.namespace;
  }
  public A withNamespace(String namespace) {
    this.namespace=namespace; return (A) this;
  }
  public Boolean hasNamespace() {
    return this.namespace != null;
  }
  public String getPath() {
    return this.path;
  }
  public A withPath(String path) {
    this.path=path; return (A) this;
  }
  public Boolean hasPath() {
    return this.path != null;
  }
  public String getServer() {
    return this.server;
  }
  public A withServer(String server) {
    this.server=server; return (A) this;
  }
  public Boolean hasServer() {
    return this.server != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    VaultIssuerFluentImpl that = (VaultIssuerFluentImpl) o;
    if (auth != null ? !auth.equals(that.auth) :that.auth != null) return false;
    if (caBundle != null ? !caBundle.equals(that.caBundle) :that.caBundle != null) return false;
    if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
    if (path != null ? !path.equals(that.path) :that.path != null) return false;
    if (server != null ? !server.equals(that.server) :that.server != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(auth,  caBundle,  namespace,  path,  server,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (auth != null) { sb.append("auth:"); sb.append(auth + ","); }
    if (caBundle != null) { sb.append("caBundle:"); sb.append(caBundle + ","); }
    if (namespace != null) { sb.append("namespace:"); sb.append(namespace + ","); }
    if (path != null) { sb.append("path:"); sb.append(path + ","); }
    if (server != null) { sb.append("server:"); sb.append(server); }
    sb.append("}");
    return sb.toString();
  }
  class AuthNestedImpl<N> extends VaultAuthFluentImpl<VaultIssuerFluent.AuthNested<N>> implements VaultIssuerFluent.AuthNested<N>,Nested<N>{
    AuthNestedImpl(VaultAuth item) {
      this.builder = new VaultAuthBuilder(this, item);
    }
    AuthNestedImpl() {
      this.builder = new VaultAuthBuilder(this);
    }
    VaultAuthBuilder builder;
    public N and() {
      return (N) VaultIssuerFluentImpl.this.withAuth(builder.build());
    }
    public N endAuth() {
      return and();
    }
    
  }
  
}

==> certmanager-model-v1alpha2-6.7.1-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/VaultIssuerFluentImpl.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class VaultIssuerFluentImpl<A extends VaultIssuerFluent<A>> extends BaseFluent<A> implements VaultIssuerFluent<A>{
  public VaultIssuerFluentImpl() {
  }
  public VaultIssuerFluentImpl(VaultIssuer instance) {
    if (instance != null) {
      this.withAuth(instance.getAuth());
      this.withCaBundle(instance.getCaBundle());
      this.withNamespace(instance.getNamespace());
      this.withPath(instance.getPath());
      this.withServer(instance.getServer());
    }
  }
  private VaultAuthBuilder auth;
  private String caBundle;
  private String namespace;
  private String path;
  private String server;
  
  /**
   * This method has been deprecated, please use method buildAuth instead.
   * @return The buildable object.
   */
  @Deprecated
  public VaultAuth getAuth() {
    return this.auth!=null ?this.auth.build():null;
  }
  public VaultAuth buildAuth() {
    return this.auth!=null ?this.auth.build():null;
  }
  public A withAuth(VaultAuth auth) {
    _visitables.get("auth").remove(this.auth);
    if (auth!=null){ this.auth= new VaultAuthBuilder(auth); _visitables.get("auth").add(this.auth);} else { this.auth = null; _visitables.get("auth").remove(this.auth); } return (A) this;
  }
  public Boolean hasAuth() {
    return this.auth != null;
  }
  public VaultIssuerFluentImpl.AuthNested<A> withNewAuth() {
    return new VaultIssuerFluentImpl.AuthNestedImpl();
  }
  public VaultIssuerFluentImpl.AuthNested<A> withNewAuthLike(VaultAuth item) {
    return new VaultIssuerFluentImpl.AuthNestedImpl(item);
  }
  public VaultIssuerFluentImpl.AuthNested<A> editAuth() {
    return withNewAuthLike(getAuth());
  }
  public VaultIssuerFluentImpl.AuthNested<A> editOrNewAuth() {
    return withNewAuthLike(getAuth() != null ? getAuth(): new VaultAuthBuilder().build());
  }
  public VaultIssuerFluentImpl.AuthNested<A> editOrNewAuthLike(VaultAuth item) {
    return withNewAuthLike(getAuth() != null ? getAuth(): item);
  }
  public String getCaBundle() {
    return this.caBundle;
  }
  public A withCaBundle(String caBundle) {
    this.caBundle=caBundle; return (A) this;
  }
  public Boolean hasCaBundle() {
    return this.caBundle != null;
  }
  public String getNamespace() {
    return this.namespace;
  }
  public A withNamespace(String namespace) {
    this.namespace=namespace; return (A) this;
  }
  public Boolean hasNamespace() {
    return this.namespace != null;
  }
  public String getPath() {
    return this.path;
  }
  public A withPath(String path) {
    this.path=path; return (A) this;
  }
  public Boolean hasPath() {
    return this.path != null;
  }
  public String getServer() {
    return this.server;
  }
  public A withServer(String server) {
    this.server=server; return (A) this;
  }
  public Boolean hasServer() {
    return this.server != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    VaultIssuerFluentImpl that = (VaultIssuerFluentImpl) o;
    if (!java.util.Objects.equals(auth, that.auth)) return false;

    if (!java.util.Objects.equals(caBundle, that.caBundle)) return false;

    if (!java.util.Objects.equals(namespace, that.namespace)) return false;

    if (!java.util.Objects.equals(path, that.path)) return false;

    if (!java.util.Objects.equals(server, that.server)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(auth,  caBundle,  namespace,  path,  server,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (auth != null) { sb.append("auth:"); sb.append(auth + ","); }
    if (caBundle != null) { sb.append("caBundle:"); sb.append(caBundle + ","); }
    if (namespace != null) { sb.append("namespace:"); sb.append(namespace + ","); }
    if (path != null) { sb.append("path:"); sb.append(path + ","); }
    if (server != null) { sb.append("server:"); sb.append(server); }
    sb.append("}");
    return sb.toString();
  }
  class AuthNestedImpl<N> extends VaultAuthFluentImpl<VaultIssuerFluentImpl.AuthNested<N>> implements VaultIssuerFluentImpl.AuthNested<N>,Nested<N>{
    AuthNestedImpl(VaultAuth item) {
      this.builder = new VaultAuthBuilder(this, item);
    }
    AuthNestedImpl() {
      this.builder = new VaultAuthBuilder(this);
    }
    VaultAuthBuilder builder;
    public N and() {
      return (N) VaultIssuerFluentImpl.this.withAuth(builder.build());
    }
    public N endAuth() {
      return and();
    }
    
  }
  
}
